pub fn inspect_bytes(_data: &[u8]) -> Result<ImageMetadata>Expand description
Inspect audio bytes and extract metadata.
Not yet implemented. Returns an error indicating audio support is planned for v2.
pub fn inspect_bytes(_data: &[u8]) -> Result<ImageMetadata>Inspect audio bytes and extract metadata.
Not yet implemented. Returns an error indicating audio support is planned for v2.